@@ -348,12 +348,12 @@ class Statement(Workflow, ModelSQL, ModelView):
 
             @property
             def amount(self):
-                return sum((l.amount for l in lines))
+                return sum((l.amount for l in self.lines))
 
             @property
             def descriptions(self):
                 done = set()
-                for line in lines:
+                for line in self.lines:
                     if line.description and line.description not in done:
                         done.add(line.description)
                         yield line.description
@@ -984,7 +984,7 @@ class Origin(origin_mixin(_states, _depends), ModelSQL, ModelView):
     informations = fields.Dict(
         'account.statement.origin.information', "Informations", readonly=True)
 
-    @fields.depends('statement')
+    @fields.depends('statement', '_parent_statement.id')
     def on_change_with_statement_id(self, name=None):
         if self.statement:
             return self.statement.id
